@@ -1,5 +1,5 @@
 package FusionInventory::Agent::Task::SNMPQuery;
-our $VERSION = '1.0';
+our $VERSION = '1.1';
 use strict;
 no strict 'refs';
 use warnings;
@@ -24,6 +24,10 @@ use FusionInventory::Agent::XML::Response::Prolog;
 use FusionInventory::Agent::Network;
 use FusionInventory::Agent::SNMP;
 
+use FusionInventory::Agent::Task::SNMPQuery::Cisco;
+use FusionInventory::Agent::Task::SNMPQuery::Procurve;
+use FusionInventory::Agent::Task::SNMPQuery::ThreeCom;
+
 use FusionInventory::Agent::AccountInfo;
 
 my $maxIdx : shared = 0;
@@ -127,7 +131,7 @@ sub StartThreads {
    my $xml_thread = {};
 
 	#===================================
-	# Threads et variables partagées
+	# Threads et variables partagÃ©es
 	#===================================
    my %TuerThread : shared;
 	my %ArgumentsThread :shared;
@@ -299,7 +303,7 @@ sub StartThreads {
                                                    $self->{logger}->debug("Core $p - Thread $t created");
 
                                                    while ($loopthread ne "1") {
-                                                      # Lance la procédure et récupère le résultat
+                                                      # Lance la procÃ©dure et rÃ©cupÃ¨re le rÃ©sultat
                                                       $device_id = "";
                                                       {
                                                          lock(%devicelist2);
@@ -318,6 +322,7 @@ sub StartThreads {
                                                                authlist            => $authlist->{$devicelist->{$device_id}->{AUTHSNMP_ID}}
                                                             });
                                                          $xml_thread->{DEVICE}->[$count] = $datadevice;
+                                                         $xml_thread->{MODULEVERSION} = $VERSION;
                                                          $xml_thread->{PROCESSNUMBER} = $self->{SNMPQUERY}->{PARAM}->[0]->{PID};
                                                          $count++;
                                                          if (($count eq "1") || (($loopthread eq "1") && ($count > 0))) {
@@ -353,6 +358,7 @@ sub StartThreads {
       my $xml_thread = {};
       $xml_thread->{AGENT}->{START} = '1';
       $xml_thread->{AGENT}->{AGENTVERSION} = $self->{config}->{VERSION};
+      $xml_thread->{MODULEVERSION} = $VERSION;
       $xml_thread->{PROCESSNUMBER} = $self->{SNMPQUERY}->{PARAM}->[0]->{PID};
       $self->SendInformations({
          data => $xml_thread
@@ -385,6 +391,7 @@ sub StartThreads {
                 $storage->remove({
                      idx => $idx
                   });
+                sleep 1;
              }
          }
       }
@@ -406,6 +413,7 @@ sub StartThreads {
                   data => $data
               });
           $sentxml->{$idx} = 1;
+          sleep 1;
        }
 
    }
@@ -454,7 +462,7 @@ sub SendInformations{
 
 sub AuthParser {
    #my ($self, $dataAuth) = @_;
-my $dataAuth = shift;
+   my $dataAuth = shift;
    my $authlist = {};
    if (ref($dataAuth->{AUTHENTICATION}) eq "HASH"){
       $authlist->{$dataAuth->{AUTHENTICATION}->{ID}} = {
@@ -539,7 +547,6 @@ sub ModelParser {
          }         
       }
    }
-         #print Dumper($modelslist);
    return $modelslist;
 }
 
@@ -548,19 +555,12 @@ sub ModelParser {
 sub query_device_threaded {
    my ($self, $params) = @_;
 
-# GESTION DES VLANS : CISCO
-# .1.3.6.1.4.1.9.9.68.1.2.2.1.2 = vlan id
-#
-# vtpVlanName	.1.3.6.1.4.1.9.9.46.1.3.1.1.4.1
-#
-
    my $ArraySNMPwalk = {};
    my $HashDataSNMP = {};
    my $datadevice = {};
    my $key;
 
 	#threads->yield;
-#print $params->{device}->{IP}."\n";
 	############### SNMP Queries ###############
    my $session = new FusionInventory::Agent::SNMP ({
 
@@ -576,12 +576,6 @@ sub query_device_threaded {
 
             });
 	if (!defined($session->{SNMPSession}->{session})) {
-		#debug($log,"[".$device->{IP}."] Error on connection","",$PID,$Bin);
-		#print("SNMP ERROR: %s.\n", $error);
-#      $datadevice->{ERROR}->{ID} = $device->{ID};
-#      $datadevice->{ERROR}->{TYPE} = $device->{TYPE};
-#      $datadevice->{ERROR}->{MESSAGE} = $error;
-#print "SNMP HS\n";
 		return $datadevice;
 	}
    my $session2 = new FusionInventory::Agent::SNMP ({
@@ -608,7 +602,6 @@ sub query_device_threaded {
 	my $insertXML = '';
 	if ($description =~ m/No response from remote host/) {
 		$error = "No response from remote host";
-		#debug($log,"[".$device->{IP}."] $error","",$PID,$Bin);
       $datadevice->{ERROR}->{ID} = $params->{device}->{ID};
       $datadevice->{ERROR}->{TYPE} = $params->{device}->{TYPE};
       $datadevice->{ERROR}->{MESSAGE} = $error;
@@ -653,42 +646,69 @@ sub query_device_threaded {
       # Conversion
 
       ($datadevice, $HashDataSNMP) = ConstructDataDeviceMultiple($HashDataSNMP,$datadevice, $self, $params->{modellist}->{WALK}->{vtpVlanName}->{OID}, $params->{modellist}->{WALK});
-#      #print "DATADEVICE WALK ========================\n";
-
-# print Dumper($datadevice);
-# print Dumper($HashDataSNMP);
 
       if ($datadevice->{INFO}->{TYPE} eq "NETWORKING") {
          # Scan for each vlan (for specific switch manufacturer && model)
-         # Implique de recréer une session spécialement pour chaque vlan : communauté@vlanID
+         # Implique de recrÃ©er une session spÃ©cialement pour chaque vlan : communautÃ©@vlanID
          if ($vlan_query eq "1") {
             while ( (my $vlan_id,my $vlan_name) = each (%{$HashDataSNMP->{'vtpVlanName'}}) ) {
+               my $vlan_id_short = $vlan_id;
+               $vlan_id_short =~ s/$params->{modellist}->{WALK}->{vtpVlanName}->{OID}//;
+               $vlan_id_short =~ s/^.//;
+                #Initiate SNMP connection on this VLAN
+               my $session = new FusionInventory::Agent::SNMP ({
+
+                              version      => $params->{authlist}->{VERSION},
+                              hostname     => $params->{device}->{IP},
+                              community    => $params->{authlist}->{COMMUNITY}."@".$vlan_id_short,
+                              username     => $params->{authlist}->{USERNAME},
+                              authpassword => $params->{authlist}->{AUTHPASSWORD},
+                              authprotocol => $params->{authlist}->{AUTHPROTOCOL},
+                              privpassword => $params->{authlist}->{PRIVPASSWORD},
+                              privprotocol => $params->{authlist}->{PRIVPROTOCOL},
+                              translate    => 1,
+
+                           });
+                  my $session2 = new FusionInventory::Agent::SNMP ({
+
+                              version      => $params->{authlist}->{VERSION},
+                              hostname     => $params->{device}->{IP},
+                              community    => $params->{authlist}->{COMMUNITY}."@".$vlan_id_short,
+                              username     => $params->{authlist}->{USERNAME},
+                              authpassword => $params->{authlist}->{AUTHPASSWORD},
+                              authprotocol => $params->{authlist}->{AUTHPROTOCOL},
+                              privpassword => $params->{authlist}->{PRIVPASSWORD},
+                              privprotocol => $params->{authlist}->{PRIVPROTOCOL},
+                              translate    => 0,
+
+                           });
+
                $ArraySNMPwalk = {};
-               $HashDataSNMP  = {};
+               #$HashDataSNMP  = {};
                for my $link ( keys %{$params->{modellist}->{WALK}} ) {
                   if ($params->{modellist}->{WALK}->{$link}->{VLAN} eq "1") {
                      $ArraySNMPwalk = $session->snmpWalk({
-                        oid_start => $params->{modellist}->{WALK}->{$link}->{OID}
+                                        oid_start => $params->{modellist}->{WALK}->{$link}->{OID}
                      });
                      $HashDataSNMP->{VLAN}->{$vlan_id}->{$link} = $ArraySNMPwalk;
                   }
                }
                # Detect mac adress on each port
                if ($datadevice->{INFO}->{COMMENTS} =~ /Cisco/) {
-                  ($datadevice, $HashDataSNMP) = Cisco_GetMAC($HashDataSNMP,$datadevice,$vlan_id,$self, $params->{modellist}->{WALK});
+                  ($datadevice, $HashDataSNMP) = FusionInventory::Agent::Task::SNMPQuery::Cisco::GetMAC($HashDataSNMP,$datadevice,$vlan_id,$self, $params->{modellist}->{WALK});
                }
                delete $HashDataSNMP->{VLAN}->{$vlan_id};
             }
          } else {
             if ($datadevice->{INFO}->{COMMENTS} =~ /3Com IntelliJack/) {
-               ($datadevice, $HashDataSNMP) = threecom_GetMAC($HashDataSNMP,$datadevice,$self,$params->{modellist}->{WALK});
+               ($datadevice, $HashDataSNMP) = FusionInventory::Agent::Task::SNMPQuery::ThreeCom::GetMAC($HashDataSNMP,$datadevice,$self,$params->{modellist}->{WALK});
+               $datadevice = FusionInventory::Agent::Task::SNMPQuery::ThreeCom::RewritePortOf225($datadevice, $self);
             } elsif ($datadevice->{INFO}->{COMMENTS} =~ /ProCurve/) {
-               ($datadevice, $HashDataSNMP) = Procurve_GetMAC($HashDataSNMP,$datadevice,$self, $params->{modellist}->{WALK});
+               ($datadevice, $HashDataSNMP) = FusionInventory::Agent::Task::SNMPQuery::Procurve::GetMAC($HashDataSNMP,$datadevice,$self, $params->{modellist}->{WALK});
             }
          }
       }
 	}
-	#debug($log,"[".$device->{infos}->{ip}."] : end Thread", "",$PID,$Bin);
    return $datadevice;
 }
 
@@ -698,8 +718,6 @@ sub ConstructDataDeviceSimple {
    my $HashDataSNMP = shift;
    my $datadevice = shift;
    if (exists $HashDataSNMP->{macaddr}) {
-#      my @array = split(/(\S{2})/, $HashDataSNMP->{macaddr});
-#      $datadevice->{INFO}->{MAC} = $array[3].":".$array[5].":".$array[7].":".$array[9].":".$array[11].":".$array[13];
       $datadevice->{INFO}->{MAC} = $HashDataSNMP->{macaddr};
       delete $HashDataSNMP->{macaddr};
    }
@@ -921,11 +939,11 @@ sub ConstructDataDeviceMultiple {
    # Detect Trunk & CDP
    if (defined ($datadevice->{INFO}->{COMMENTS})) {
       if ($datadevice->{INFO}->{COMMENTS} =~ /Cisco/) {
-         ($datadevice, $HashDataSNMP) = Cisco_TrunkPorts($HashDataSNMP,$datadevice, $self);
-         ($datadevice, $HashDataSNMP) = Cisco_CDPPorts($HashDataSNMP,$datadevice, $walkoid, $self);
+         ($datadevice, $HashDataSNMP) = FusionInventory::Agent::Task::SNMPQuery::Cisco::TrunkPorts($HashDataSNMP,$datadevice, $self);
+         ($datadevice, $HashDataSNMP) = FusionInventory::Agent::Task::SNMPQuery::Cisco::CDPPorts($HashDataSNMP,$datadevice, $walkoid, $self);
       } elsif ($datadevice->{INFO}->{COMMENTS} =~ /ProCurve/) {
-         ($datadevice, $HashDataSNMP) = Cisco_TrunkPorts($HashDataSNMP,$datadevice, $self);
-         ($datadevice, $HashDataSNMP) = Cisco_CDPPorts($HashDataSNMP,$datadevice, $walkoid, $self);
+         ($datadevice, $HashDataSNMP) = FusionInventory::Agent::Task::SNMPQuery::Cisco::TrunkPorts($HashDataSNMP,$datadevice, $self);
+         ($datadevice, $HashDataSNMP) = FusionInventory::Agent::Task::SNMPQuery::Cisco::CDPPorts($HashDataSNMP,$datadevice, $walkoid, $self);
       }
    }
 
@@ -953,6 +971,10 @@ sub PutSimpleOid {
       if (($element eq "ram") || ($element eq "memory")) {
          $HashDataSNMP->{$element} = int(( $HashDataSNMP->{$element} / 1024 ) / 1024);
       }
+      if ($element eq "serial") {
+         $HashDataSNMP->{$element} =~ s/^\s+//;
+         $HashDataSNMP->{$element} =~ s/\s+$//;
+      }
       if ($element eq "firmware1") {
          $datadevice->{$xmlelement1}->{$xmlelement2} = $HashDataSNMP->{"firmware1"}." ".$HashDataSNMP->{"firmware2"};
          delete $HashDataSNMP->{"firmware2"};
@@ -980,10 +1002,11 @@ sub PutPourcentageOid {
    my $xmlelement1 = shift;
    my $xmlelement2 = shift;
    if (exists $HashDataSNMP->{$element1}) {
-      $datadevice->{$xmlelement1}->{$xmlelement2} = int ( ( 100 * $HashDataSNMP->{$element2} )
-      / $HashDataSNMP->{$element1} );
-      delete $HashDataSNMP->{$element2};
-      delete $HashDataSNMP->{$element1};
+      if ((is_integer($HashDataSNMP->{$element2})) && (is_integer($HashDataSNMP->{$element1}))) {
+         $datadevice->{$xmlelement1}->{$xmlelement2} = int ( ( 100 * $HashDataSNMP->{$element2} ) / $HashDataSNMP->{$element1} );
+         delete $HashDataSNMP->{$element2};
+         delete $HashDataSNMP->{$element1};
+      }
    }
    return $datadevice, $HashDataSNMP;
 }
@@ -1016,215 +1039,9 @@ sub cartridgesupport {
 }
 
 
-#############################################################################
-######################## MANUFACTURER SPECIFICATIONS ########################
-#############################################################################
-
-sub Cisco_TrunkPorts {
-   my $HashDataSNMP = shift,
-   my $datadevice = shift;
-   my $self = shift;
-
-   while ( (my $port_id, my $trunk) = each (%{$HashDataSNMP->{vlanTrunkPortDynamicStatus}}) ) {
-      if ($trunk eq "1") {
-         $datadevice->{PORTS}->{PORT}->[$self->{portsindex}->{lastSplitObject($port_id)}]->{TRUNK} = $trunk;
-      } else {
-         $datadevice->{PORTS}->{PORT}->[$self->{portsindex}->{lastSplitObject($port_id)}]->{TRUNK} = '0';
-      }
-      delete $HashDataSNMP->{vlanTrunkPortDynamicStatus}->{$port_id};
-   }
-   if (keys (%{$HashDataSNMP->{vlanTrunkPortDynamicStatus}}) eq "0") {
-      delete $HashDataSNMP->{vlanTrunkPortDynamicStatus};
-   }
-   return $datadevice, $HashDataSNMP;
-}
-
-sub Cisco_CDPPorts {
-   my $HashDataSNMP = shift,
-   my $datadevice = shift;
-   my $oid_walks = shift;
-   my $self = shift;
-   
-   my $short_number;
-
-   while ( my ( $number, $ip_hex) = each (%{$HashDataSNMP->{cdpCacheAddress}}) ) {
-      $ip_hex =~ s/://g;
-      $short_number = $number;
-      $short_number =~ s/$oid_walks->{cdpCacheAddress}->{OID}//;
-      my @array = split(/\./, $short_number);
-      my @ip_num = split(/(\S{2})/, $ip_hex);
-      my $ip = (hex $ip_num[3]).".".(hex $ip_num[5]).".".(hex $ip_num[7]).".".(hex $ip_num[9]);
-      $datadevice->{PORTS}->{PORT}->[$self->{portsindex}->{$array[1]}]->{CONNECTIONS}->{CONNECTION}->{IP} = $ip;
-      $datadevice->{PORTS}->{PORT}->[$self->{portsindex}->{$array[1]}]->{CONNECTIONS}->{CDP} = "1";
-      $datadevice->{PORTS}->{PORT}->[$self->{portsindex}->{$array[1]}]->{CONNECTIONS}->{CONNECTION}->{IFDESCR} = $HashDataSNMP->{cdpCacheDevicePort}->{$oid_walks->{cdpCacheDevicePort}->{OID}.$short_number};
-
-      delete $HashDataSNMP->{cdpCacheAddress}->{$number};
-      delete $HashDataSNMP->{cdpCacheDevicePort}->{$number};
-   }
-   if (keys (%{$HashDataSNMP->{cdpCacheAddress}}) eq "0") {
-      delete $HashDataSNMP->{cdpCacheAddress};
-   }
-   if (keys (%{$HashDataSNMP->{cdpCacheDevicePort}}) eq "0") {
-      delete $HashDataSNMP->{cdpCacheDevicePort};
-   }
-   return $datadevice, $HashDataSNMP;
+sub is_integer {
+   $_[0] =~ /^[+-]?\d+$/;
 }
 
 
-sub Cisco_GetMAC {
-   my $HashDataSNMP = shift,
-   my $datadevice = shift;
-   my $vlan_id = shift;
-   my $self = shift;
-   my $oid_walks = shift;
-
-   my $ifIndex;
-   my $numberip;
-   my $mac;
-   my $short_number;
-   my $dot1dTpFdbPort;
-
-   my $i = 0;
-
-   # each VLAN WALK per port
-   while ( my ($number,$ifphysaddress) = each (%{$HashDataSNMP->{VLAN}->{$vlan_id}->{dot1dTpFdbAddress}}) ) {
-      $short_number = $number;
-      $short_number =~ s/$oid_walks->{dot1dTpFdbAddress}->{OID}//;
-      $dot1dTpFdbPort = $oid_walks->{dot1dTpFdbPort}->{OID};
-      if (exists $HashDataSNMP->{VLAN}->{$vlan_id}->{dot1dTpFdbPort}->{$dot1dTpFdbPort.$short_number}) {
-         if (exists $HashDataSNMP->{VLAN}->{$vlan_id}->{dot1dBasePortIfIndex}->{
-                              $oid_walks->{dot1dBasePortIfIndex}->{OID}.".".
-                              $HashDataSNMP->{VLAN}->{$vlan_id}->{dot1dTpFdbPort}->{$dot1dTpFdbPort.$short_number}
-                           }) {
-
-            $ifIndex = $HashDataSNMP->{VLAN}->{$vlan_id}->{dot1dBasePortIfIndex}->{
-                              $oid_walks->{dot1dBasePortIfIndex}->{OID}.".".
-                              $HashDataSNMP->{VLAN}->{$vlan_id}->{dot1dTpFdbPort}->{$dot1dTpFdbPort.$short_number}
-                           };
-            if (not exists $datadevice->{PORTS}->{PORT}->[$self->{portsindex}->{$ifIndex}]->{CONNECTIONS}->{CDP}) {
-               my $add = 1;
-               if ($ifphysaddress eq "") {
-                  $add = 0;
-               }
-               if ($ifphysaddress eq $datadevice->{PORTS}->{PORT}->[$self->{portsindex}->{$ifIndex}]->{MAC}) {
-                  $add = 0;
-               }
-               if ($add eq "1") {
-                  if (exists $datadevice->{PORTS}->{PORT}->[$self->{portsindex}->{$ifIndex}]->{CONNECTIONS}->{CONNECTION}) {
-                     $i = @{$datadevice->{PORTS}->{PORT}->[$self->{portsindex}->{$ifIndex}]->{CONNECTIONS}->{CONNECTION}};
-                     #$i++;
-                  } else {
-                     $i = 0;
-                  }
-                  $datadevice->{PORTS}->{PORT}->[$self->{portsindex}->{$ifIndex}]->{CONNECTIONS}->{CONNECTION}->[$i]->{MAC} = $ifphysaddress;
-                  $i++;
-               }
-            }
-         }
-      }
-      delete $HashDataSNMP->{VLAN}->{$vlan_id}->{dot1dTpFdbAddress}->{$number};
-      delete $HashDataSNMP->{VLAN}->{$vlan_id}->{dot1dTpFdbPort}->{$dot1dTpFdbPort.$short_number};
-   }
-   return $datadevice, $HashDataSNMP;
-}
-
-
-sub threecom_GetMAC {
-   my $HashDataSNMP = shift,
-   my $datadevice = shift;
-   my $self = shift;
-   my $oid_walks = shift;
-
-   my $ifIndex;
-   my $numberip;
-   my $mac;
-   my $short_number;
-   my $dot1dTpFdbPort;
-   my $add = 0;
-   my $i;
-   
-   while ( my ($number,$ifphysaddress) = each (%{$HashDataSNMP->{dot1dTpFdbAddress}}) ) {
-      $short_number = $number;
-      $short_number =~ s/$oid_walks->{dot1dTpFdbAddress}->{OID}//;
-      $dot1dTpFdbPort = $oid_walks->{dot1dTpFdbPort}->{OID};
-      
-      $add = 1;
-      if ($ifphysaddress eq "") {
-         $add = 0;
-      }
-      if (($add eq "1") && (exists($HashDataSNMP->{dot1dTpFdbPort}->{$dot1dTpFdbPort.$short_number}))) {
-         $ifIndex = $HashDataSNMP->{dot1dBasePortIfIndex}->{
-               $oid_walks->{dot1dBasePortIfIndex}->{OID}.".".
-               $HashDataSNMP->{dot1dTpFdbPort}->{$dot1dTpFdbPort.$short_number}
-            };
-
-         if (exists $datadevice->{PORTS}->{PORT}->[$self->{portsindex}->{$ifIndex}]->{CONNECTIONS}->{CONNECTION}) {
-            $i = @{$datadevice->{PORTS}->{PORT}->[$self->{portsindex}->{$ifIndex}]->{CONNECTIONS}->{CONNECTION}};
-         } else {
-            $i = 0;
-         }
-         $datadevice->{PORTS}->{PORT}->[$self->{portsindex}->{$ifIndex}]->{CONNECTIONS}->{CONNECTION}->[$i]->{MAC} = $ifphysaddress;
-         $i++;
-      }
-   }
-   return $datadevice, $HashDataSNMP;
-}
-
-
-
-sub Procurve_GetMAC {
-   my $HashDataSNMP = shift,
-   my $datadevice = shift;
-   my $self = shift;
-   my $oid_walks = shift;
-
-   my $ifIndex;
-   my $numberip;
-   my $mac;
-   my $short_number;
-   my $dot1dTpFdbPort;
-
-   my $i = 0;
-
-   while ( my ($number,$ifphysaddress) = each (%{$HashDataSNMP->{dot1dTpFdbAddress}}) ) {
-      $short_number = $number;
-      $short_number =~ s/$oid_walks->{dot1dTpFdbAddress}->{OID}//;
-      $dot1dTpFdbPort = $oid_walks->{dot1dTpFdbPort}->{OID};
-      if (exists $HashDataSNMP->{dot1dTpFdbPort}->{$dot1dTpFdbPort.$short_number}) {
-         if (exists $HashDataSNMP->{dot1dBasePortIfIndex}->{
-                              $oid_walks->{dot1dBasePortIfIndex}->{OID}.".".
-                              $HashDataSNMP->{dot1dTpFdbPort}->{$dot1dTpFdbPort.$short_number}
-                           }) {
-
-            $ifIndex = $HashDataSNMP->{dot1dBasePortIfIndex}->{
-                              $oid_walks->{dot1dBasePortIfIndex}->{OID}.".".
-                              $HashDataSNMP->{dot1dTpFdbPort}->{$dot1dTpFdbPort.$short_number}
-                           };
-            if (not exists $datadevice->{PORTS}->{PORT}->[$self->{portsindex}->{$ifIndex}]->{CONNECTIONS}->{CDP}) {
-               my $add = 1;
-               if ($ifphysaddress eq "") {
-                  $add = 0;
-               }
-               if ($ifphysaddress eq $datadevice->{PORTS}->{PORT}->[$self->{portsindex}->{$ifIndex}]->{MAC}) {
-                  $add = 0;
-               }
-               if ($add eq "1") {
-                  if (exists $datadevice->{PORTS}->{PORT}->[$self->{portsindex}->{$ifIndex}]->{CONNECTIONS}->{CONNECTION}) {
-                     $i = @{$datadevice->{PORTS}->{PORT}->[$self->{portsindex}->{$ifIndex}]->{CONNECTIONS}->{CONNECTION}};
-                     #$i++;
-                  } else {
-                     $i = 0;
-                  }
-                  $datadevice->{PORTS}->{PORT}->[$self->{portsindex}->{$ifIndex}]->{CONNECTIONS}->{CONNECTION}->[$i]->{MAC} = $ifphysaddress;
-                  $i++;
-               }
-            }
-         }
-      }
-      delete $HashDataSNMP->{dot1dTpFdbAddress}->{$number};
-      delete $HashDataSNMP->{dot1dTpFdbPort}->{$dot1dTpFdbPort.$short_number};
-   }
-   return $datadevice, $HashDataSNMP;
-}
-
-1;
+1;
\ No newline at end of file
